@@ -18,26 +18,28 @@
 */
 
 #include "PriorityQueue.h"
-#include "Utilities/AlgorithmHelper.h"
+
+#include <Utilities/AlgorithmHelper.h>
+
 #include <functional>
 
 using namespace Utilities;
-namespace BackgroundTaskManager {
+namespace BackgroundTaskManager
+{
 
 PriorityQueue::PriorityQueue()
 {
     m_jobs.resize(SIZE_OF_PRIORITY_QUEUE);
 }
 
-
 bool PriorityQueue::isEmpty() const
 {
-    return all_of( m_jobs, std::mem_fn(&QueueType::isEmpty) );
+    return all_of(m_jobs, std::mem_fn(&QueueType::isEmpty));
 }
 
 int PriorityQueue::count() const
 {
-    return sum( m_jobs, std::mem_fn(&QueueType::length ) );
+    return sum(m_jobs, std::mem_fn(&QueueType::length));
 }
 
 void PriorityQueue::enqueue(JobInterface *job, Priority priority)
@@ -47,30 +49,30 @@ void PriorityQueue::enqueue(JobInterface *job, Priority priority)
 
 JobInterface *PriorityQueue::dequeue()
 {
-    for( QueueType& queue : m_jobs ) {
-        if ( !queue.isEmpty() )
+    for (QueueType &queue : m_jobs) {
+        if (!queue.isEmpty())
             return queue.dequeue();
     }
-    Q_ASSERT( false && "Queue was empty");
+    Q_ASSERT(false && "Queue was empty");
     return nullptr;
 }
 
 JobInterface *PriorityQueue::peek(int index) const
 {
     int offset = 0;
-    for ( const QueueType& queue : m_jobs) {
-        if ( index-offset < queue.count() )
-            return queue[index-offset];
+    for (const QueueType &queue : m_jobs) {
+        if (index - offset < queue.count())
+            return queue[index - offset];
         else
             offset += queue.count();
     }
-    Q_ASSERT( false && "index beyond queue");
+    Q_ASSERT(false && "index beyond queue");
     return nullptr;
 }
 
 bool PriorityQueue::hasForegroundTasks() const
 {
-    for (int i = 0; i < BackgroundTask; ++i ) {
+    for (int i = 0; i < BackgroundTask; ++i) {
         if (!m_jobs[i].isEmpty())
             return true;
     }
