@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2010 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2019 The KPhotoAlbum Development Team
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -49,10 +49,10 @@ public:
     bool showDuringMovement() const override;
 
 public slots:
-    void slotNewRegionSelected(KGeoMap::GeoCoordinates::Pair coordinates);
+    void slotNewRegionSelected(Map::GeoCoordinates::LatLonBox coordinates);
 
 private:
-    bool active;
+    bool m_active;
 };
 
 }
