@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2018 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2019 The KPhotoAlbum Development Team
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -19,14 +19,14 @@
 
 using namespace DB;
 
-void CategoryCollection::itemRenamed( const QString& oldName, const QString& newName )
+void CategoryCollection::slotItemRenamed(const QString &oldName, const QString &newName)
 {
-    emit itemRenamed( static_cast<Category*>( const_cast<QObject*>( sender() ) ), oldName, newName );
+    emit itemRenamed(static_cast<Category *>(const_cast<QObject *>(sender())), oldName, newName);
 }
 
-void CategoryCollection::itemRemoved( const QString& item )
+void CategoryCollection::slotItemRemoved(const QString &item)
 {
-    emit itemRemoved( static_cast<Category*>( const_cast<QObject*>( sender() ) ), item );
+    emit itemRemoved(static_cast<Category *>(const_cast<QObject *>(sender())), item);
 }
 
 // vi:expandtab:tabstop=4 shiftwidth=4:
