@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2010 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2019 The KPhotoAlbum Development Team
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -17,25 +17,26 @@
 */
 #include "ImageRequest.h"
 
-ImageManager::ImageRequest::ImageRequest( const DB::FileName& fileName,
-                                          const QSize& size, int angle,
-                                          ImageManager::ImageClientInterface* client )
-    : m_null( false ),
-      m_fileName( fileName ),
-      m_width( size.width() ),
-      m_height( size.height() ),
-      m_client( client ),
-      m_angle( angle ),
-      m_priority( ThumbnailVisible ),
-      m_loadedOK( false ),
-      m_dontUpScale( false ),
-      m_isThumbnailRequest(false),
-      m_isExitRequest(false)
+ImageManager::ImageRequest::ImageRequest(const DB::FileName &fileName,
+                                         const QSize &size, int angle,
+                                         ImageManager::ImageClientInterface *client)
+    : m_null(false)
+    , m_fileName(fileName)
+    , m_width(size.width())
+    , m_height(size.height())
+    , m_client(client)
+    , m_angle(angle)
+    , m_priority(ThumbnailVisible)
+    , m_loadedOK(false)
+    , m_dontUpScale(false)
+    , m_isThumbnailRequest(false)
+    , m_isExitRequest(false)
+    , m_imageIsPreRotated(false)
 {
 }
 
-ImageManager::ImageRequest::ImageRequest( bool requestExit )
-    : m_isExitRequest( requestExit )
+ImageManager::ImageRequest::ImageRequest(bool requestExit)
+    : m_isExitRequest(requestExit)
 {
 }
 
@@ -44,6 +45,16 @@ bool ImageManager::ImageRequest::isExitRequest() const
     return m_isExitRequest;
 }
 
+bool ImageManager::ImageRequest::imageIsPreRotated() const
+{
+    return m_imageIsPreRotated;
+}
+
+void ImageManager::ImageRequest::setImageIsPreRotated(bool imageIsPreRotated)
+{
+    m_imageIsPreRotated = imageIsPreRotated;
+}
+
 bool ImageManager::ImageRequest::loadedOK() const
 {
     return m_loadedOK;
@@ -64,31 +75,28 @@ int ImageManager::ImageRequest::height() const
     return m_height;
 }
 
-bool ImageManager::ImageRequest::operator<( const ImageRequest& other ) const
+bool ImageManager::ImageRequest::operator<(const ImageRequest &other) const
 {
     const DB::FileName fileA = databaseFileName();
     const DB::FileName fileB = other.databaseFileName();
 
-    if (  fileA != fileB )
+    if (fileA != fileB)
         return fileA < fileB;
-    else if ( m_width != other.m_width )
+    else if (m_width != other.m_width)
         return m_width < other.m_width;
-    else if ( m_height != other.m_height )
+    else if (m_height != other.m_height)
         return m_height < other.m_height;
     else
         return m_angle < other.m_angle;
 }
 
-bool ImageManager::ImageRequest::operator==( const ImageRequest& other ) const
+bool ImageManager::ImageRequest::operator==(const ImageRequest &other) const
 {
     // Compare all atributes but the pixmap.
-    return ( m_null == other.m_null && databaseFileName() == other.databaseFileName() &&
-             m_width == other.m_width && m_height == other.m_height &&
-             m_angle == other.m_angle && m_client == other.m_client &&
-             m_priority == other.m_priority );
+    return (m_null == other.m_null && databaseFileName() == other.databaseFileName() && m_width == other.m_width && m_height == other.m_height && m_angle == other.m_angle && m_client == other.m_client && m_priority == other.m_priority);
 }
 
-ImageManager::ImageClientInterface* ImageManager::ImageRequest::client() const
+ImageManager::ImageClientInterface *ImageManager::ImageRequest::client() const
 {
     return m_client;
 }
@@ -103,12 +111,12 @@ QSize ImageManager::ImageRequest::fullSize() const
     return m_fullSize;
 }
 
-void ImageManager::ImageRequest::setFullSize( const QSize& size )
+void ImageManager::ImageRequest::setFullSize(const QSize &size)
 {
     m_fullSize = size;
 }
 
-void ImageManager::ImageRequest::setLoadedOK( bool ok )
+void ImageManager::ImageRequest::setLoadedOK(bool ok)
 {
     m_loadedOK = ok;
 }
@@ -118,7 +126,7 @@ ImageManager::Priority ImageManager::ImageRequest::priority() const
     return m_priority;
 }
 
-void ImageManager::ImageRequest::setPriority( const Priority prio )
+void ImageManager::ImageRequest::setPriority(const Priority prio)
 {
     m_priority = prio;
 }
@@ -133,12 +141,12 @@ bool ImageManager::ImageRequest::doUpScale() const
     return !m_dontUpScale;
 }
 
-void ImageManager::ImageRequest::setUpScale( bool b )
+void ImageManager::ImageRequest::setUpScale(bool b)
 {
     m_dontUpScale = !b;
 }
 
-void ImageManager::ImageRequest::setIsThumbnailRequest( bool b )
+void ImageManager::ImageRequest::setIsThumbnailRequest(bool b)
 {
     m_isThumbnailRequest = b;
 }
@@ -160,7 +168,7 @@ DB::FileName ImageManager::ImageRequest::fileSystemFileName() const
 
 QSize ImageManager::ImageRequest::size() const
 {
-    return QSize( m_width, m_height );
+    return QSize(m_width, m_height);
 }
 
 // vi:expandtab:tabstop=4 shiftwidth=4:
