@@ -18,6 +18,7 @@
 */
 
 #include "VideoLengthExtractor.h"
+
 #include "Logging.h"
 
 #include <MainWindow/FeatureDialog.h>
@@ -27,16 +28,17 @@
 
 #define STR(x) QString::fromUtf8(x)
 
-ImageManager::VideoLengthExtractor::VideoLengthExtractor(QObject *parent) :
-    QObject(parent), m_process(nullptr)
+ImageManager::VideoLengthExtractor::VideoLengthExtractor(QObject *parent)
+    : QObject(parent)
+    , m_process(nullptr)
 {
 }
 
 void ImageManager::VideoLengthExtractor::extract(const DB::FileName &fileName)
 {
     m_fileName = fileName;
-    if ( m_process ) {
-        disconnect( m_process, SIGNAL(finished(int)), this, SLOT(processEnded()));
+    if (m_process) {
+        disconnect(m_process, SIGNAL(finished(int)), this, SLOT(processEnded()));
         m_process->kill();
         delete m_process;
         m_process = nullptr;
@@ -49,14 +51,14 @@ void ImageManager::VideoLengthExtractor::extract(const DB::FileName &fileName)
 
     m_process = new Utilities::Process(this);
     m_process->setWorkingDirectory(QDir::tempPath());
-    connect( m_process, SIGNAL(finished(int)), this, SLOT(processEnded()));
+    connect(m_process, SIGNAL(finished(int)), this, SLOT(processEnded()));
 
-    Q_ASSERT( MainWindow::FeatureDialog::hasVideoProber() );
+    Q_ASSERT(MainWindow::FeatureDialog::hasVideoProber());
     QStringList arguments;
     // Just look at the length of the container. Some videos have streams without duration entry
     arguments << STR("-v") << STR("0") << STR("-show_entries") << STR("format=duration")
               << STR("-of") << STR("default=noprint_wrappers=1:nokey=1")
-              <<  fileName.absolute();
+              << fileName.absolute();
 
     qCDebug(ImageManagerLog, "%s %s", qPrintable(MainWindow::FeatureDialog::ffprobeBinary()), qPrintable(arguments.join(QString::fromLatin1(" "))));
     m_process->start(MainWindow::FeatureDialog::ffprobeBinary(), arguments);
@@ -64,12 +66,12 @@ void ImageManager::VideoLengthExtractor::extract(const DB::FileName &fileName)
 
 void ImageManager::VideoLengthExtractor::processEnded()
 {
-    if ( !m_process->stdErr().isEmpty() )
+    if (!m_process->stdErr().isEmpty())
         qCDebug(ImageManagerLog) << m_process->stdErr();
 
     const QStringList list = m_process->stdOut().split(QChar::fromLatin1('\n'));
     // ffprobe -v 0 just prints one line, except if panicking
-    if ( list.count() < 1 ) {
+    if (list.count() < 1) {
         qCWarning(ImageManagerLog) << "Unable to parse video length from ffprobe output!"
                                    << "Output was:\n"
                                    << m_process->stdOut();
@@ -80,13 +82,13 @@ void ImageManager::VideoLengthExtractor::processEnded()
 
     bool ok = false;
     const double length = lenStr.toDouble(&ok);
-    if ( !ok ) {
+    if (!ok) {
         qCWarning(ImageManagerLog) << STR("Unable to convert string \"%1\"to double (for file %2)").arg(lenStr).arg(m_fileName.absolute());
         emit unableToDetermineLength();
         return;
     }
 
-    if ( length == 0 ) {
+    if (length == 0) {
         qCWarning(ImageManagerLog) << "video length returned was 0 for file " << m_fileName.absolute();
         emit unableToDetermineLength();
         return;
