@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2018 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2020 The KPhotoAlbum Development Team
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -20,6 +20,7 @@
 
 #include "ImportSettings.h"
 
+#include <KColorScheme>
 #include <KLocalizedString>
 #include <QGridLayout>
 #include <QVBoxLayout>
@@ -47,21 +48,18 @@ ImportMatcher::ImportMatcher(const QString &otherCategory, const QString &myCate
     setWidget(top);
 
     QLabel *label = new QLabel(i18n("Key in file"), grid);
-    gridLay->addWidget(label, 0, 0);
-
-    QPalette pal = label->palette();
-    QColor col = pal.color(QPalette::Background);
     label->setAutoFillBackground(true);
-    pal.setColor(QPalette::Background, pal.color(QPalette::Foreground));
-    pal.setColor(QPalette::Foreground, col);
-    label->setPalette(pal);
+    label->setForegroundRole(QPalette::Dark);
+    label->setBackgroundRole(QPalette::BrightText);
     label->setAlignment(Qt::AlignCenter);
+    gridLay->addWidget(label, 0, 0);
 
     label = new QLabel(i18n("Key in your database"), grid);
     label->setAutoFillBackground(true);
-    gridLay->addWidget(label, 0, 1);
-    label->setPalette(pal);
+    label->setForegroundRole(QPalette::Dark);
+    label->setBackgroundRole(QPalette::BrightText);
     label->setAlignment(Qt::AlignCenter);
+    gridLay->addWidget(label, 0, 1);
 
     int row = 1;
     for (QStringList::ConstIterator it = otherItems.begin(); it != otherItems.end(); ++it) {
@@ -112,9 +110,6 @@ CategoryMatch::CategoryMatch(bool allowNew, const QString &kimFileItem, QStringL
             } else
                 m_checkbox->setChecked(false);
         }
-        QPalette pal = m_checkbox->palette();
-        pal.setColor(QPalette::ButtonText, Qt::red);
-        m_checkbox->setPalette(pal);
     }
 }
 
