@@ -1,19 +1,20 @@
-/* Copyright (C) 2003-2018 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2020 The KPhotoAlbum Development Team
 
    This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   modify it under the terms of the GNU General Public License as
+   published by the Free Software Foundation; either version 2 of
+   the License or (at your option) version 3 or any later version
+   accepted by the membership of KDE e. V. (or its successor approved
+   by the membership of KDE e. V.), which shall act as a proxy
+   defined in Section 14 of version 3 of the license.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+   GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include "MiniViewer.h"
@@ -23,10 +24,10 @@
 #include <KLocalizedString>
 #include <QDialogButtonBox>
 #include <QPushButton>
-#include <qimage.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qmatrix.h>
+#include <QImage>
+#include <QLabel>
+#include <QLayout>
+#include <QTransform>
 
 using namespace ImportExport;
 
@@ -38,7 +39,7 @@ void MiniViewer::show(QImage img, DB::ImageInfoPtr info, QWidget *parent)
         s_instance = new MiniViewer(parent);
 
     if (info->angle() != 0) {
-        QMatrix matrix;
+        QTransform matrix;
         matrix.rotate(info->angle());
         img = img.transformed(matrix);
     }
