@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2019 The KPhotoAlbum Development Team
+/* Copyright (C) 2003-2020 The KPhotoAlbum Development Team
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -50,7 +50,7 @@ public:
     static bool hasVideoProber();
 
 protected:
-    static bool hasKIPISupport();
+    static bool hasPurposeSupport();
     static bool hasEXIV2Support();
     static bool hasEXIV2DBSupport();
     static bool hasGeoMapSupport();
