@@ -18,28 +18,29 @@
 
 #include "RemoteCommand.h"
 
+#include "Serializer.h"
+
+#include <QDebug>
 #include <QElapsedTimer>
 #include <QMap>
-#include <QDebug>
 #include <QPainter>
 #include <functional>
 #include <memory>
-#include "Serializer.h"
 
 using namespace RemoteControl;
 
-#define ENUMSTREAM(TYPE) \
-QDataStream &operator<<(QDataStream &stream, TYPE type) \
-{\
-    stream << (qint32) type;\
-    return stream;\
-}\
-\
-QDataStream &operator>>(QDataStream &stream, TYPE& type)\
-{\
-    stream >> (qint32&) type;\
-    return stream;\
-}\
+#define ENUMSTREAM(TYPE)                                     \
+    QDataStream &operator<<(QDataStream &stream, TYPE type)  \
+    {                                                        \
+        stream << (qint32)type;                              \
+        return stream;                                       \
+    }                                                        \
+                                                             \
+    QDataStream &operator>>(QDataStream &stream, TYPE &type) \
+    {                                                        \
+        stream >> (qint32 &)type;                            \
+        return stream;                                       \
+    }
 
 ENUMSTREAM(ViewType)
 ENUMSTREAM(SearchType)
@@ -55,15 +56,15 @@ RemoteCommand::~RemoteCommand()
     qDeleteAll(m_serializers);
 }
 
-void RemoteCommand::encode(QDataStream& stream) const
+void RemoteCommand::encode(QDataStream &stream) const
 {
-    for (SerializerInterface* serializer : m_serializers)
+    for (SerializerInterface *serializer : m_serializers)
         serializer->encode(stream);
 }
 
-void RemoteCommand::decode(QDataStream& stream)
+void RemoteCommand::decode(QDataStream &stream)
 {
-    for (SerializerInterface* serializer : m_serializers)
+    for (SerializerInterface *serializer : m_serializers)
         serializer->decode(stream);
 }
 
@@ -78,9 +79,9 @@ void RemoteCommand::addSerializer(SerializerInterface *serializer)
 }
 
 using CommandFacory = std::function<std::unique_ptr<RemoteCommand>()>;
-#define ADDFACTORY(COMMAND)\
-   factories.insert(CommandType::COMMAND, \
-       []() { return std::unique_ptr<RemoteCommand>(new COMMAND);} )
+#define ADDFACTORY(COMMAND)                \
+    factories.insert(CommandType::COMMAND, \
+                     []() { return std::unique_ptr<RemoteCommand>(new COMMAND); })
 
 std::unique_ptr<RemoteCommand> RemoteCommand::create(CommandType id)
 {
@@ -104,8 +105,12 @@ std::unique_ptr<RemoteCommand> RemoteCommand::create(CommandType id)
     return factories[id]();
 }
 
-ThumbnailResult::ThumbnailResult(ImageId _imageId, const QString& _label, const QImage& _image, ViewType _type)
-    :RemoteCommand(CommandType::ThumbnailResult), imageId(_imageId), label(_label), image(_image), type(_type)
+ThumbnailResult::ThumbnailResult(ImageId _imageId, const QString &_label, const QImage &_image, ViewType _type)
+    : RemoteCommand(CommandType::ThumbnailResult)
+    , imageId(_imageId)
+    , label(_label)
+    , image(_image)
+    , type(_type)
 {
     addSerializer(new Serializer<ImageId>(imageId));
     addSerializer(new Serializer<QString>(label));
@@ -113,14 +118,14 @@ ThumbnailResult::ThumbnailResult(ImageId _imageId, const QString& _label, const
     addSerializer(new Serializer<ViewType>(type));
 }
 
-QDataStream& operator<<(QDataStream& stream, const Category& category)
+QDataStream &operator<<(QDataStream &stream, const Category &category)
 {
-    stream << category.name << category.enabled << (int) category.viewType;
+    stream << category.name << category.enabled << (int)category.viewType;
     fastStreamImage(stream, category.icon, BackgroundType::Transparent);
     return stream;
 }
 
-QDataStream& operator>>(QDataStream& stream, Category& category)
+QDataStream &operator>>(QDataStream &stream, Category &category)
 {
     int tmp;
     stream >> category.name >> category.enabled >> tmp;
@@ -135,23 +140,31 @@ CategoryListResult::CategoryListResult()
     addSerializer(new Serializer<QList<Category>>(categories));
 }
 
-SearchRequest::SearchRequest(SearchType _type, const SearchInfo& _searchInfo, int _size)
-    :RemoteCommand(CommandType::SearchRequest), type(_type), searchInfo(_searchInfo), size(_size)
+SearchRequest::SearchRequest(SearchType _type, const SearchInfo &_searchInfo, int _size)
+    : RemoteCommand(CommandType::SearchRequest)
+    , type(_type)
+    , searchInfo(_searchInfo)
+    , size(_size)
 {
     addSerializer(new Serializer<SearchType>(type));
     addSerializer(new Serializer<SearchInfo>(searchInfo));
     addSerializer(new Serializer<int>(size));
 }
 
-SearchResult::SearchResult(SearchType _type, const QList<int>& _result)
-    :RemoteCommand(CommandType::SearchResult), type(_type), result(_result)
+SearchResult::SearchResult(SearchType _type, const QList<int> &_result)
+    : RemoteCommand(CommandType::SearchResult)
+    , type(_type)
+    , result(_result)
 {
     addSerializer(new Serializer<SearchType>(type));
     addSerializer(new Serializer<QList<int>>(result));
 }
 
-ThumbnailRequest::ThumbnailRequest(ImageId _imageId, const QSize& _size, ViewType _type)
-    :RemoteCommand(CommandType::ThumbnailRequest), imageId(_imageId), size(_size), type(_type)
+ThumbnailRequest::ThumbnailRequest(ImageId _imageId, const QSize &_size, ViewType _type)
+    : RemoteCommand(CommandType::ThumbnailRequest)
+    , imageId(_imageId)
+    , size(_size)
+    , type(_type)
 {
     addSerializer(new Serializer<ImageId>(imageId));
     addSerializer(new Serializer<QSize>(size));
@@ -159,14 +172,16 @@ ThumbnailRequest::ThumbnailRequest(ImageId _imageId, const QSize& _size, ViewTyp
 }
 
 RemoteControl::ThumbnailCancelRequest::ThumbnailCancelRequest(ImageId _imageId, ViewType _type)
-    :RemoteCommand(CommandType::ThumbnailCancelRequest), imageId(_imageId), type(_type)
+    : RemoteCommand(CommandType::ThumbnailCancelRequest)
+    , imageId(_imageId)
+    , type(_type)
 {
     addSerializer(new Serializer<ImageId>(imageId));
     addSerializer(new Serializer<ViewType>(type));
 }
 
 TimeCommand::TimeCommand()
-    :RemoteCommand(CommandType::TimeCommand)
+    : RemoteCommand(CommandType::TimeCommand)
 {
 }
 
@@ -177,67 +192,75 @@ static void printElapsed()
     timer.restart();
 }
 
-void TimeCommand::encode(QDataStream&) const
+void TimeCommand::encode(QDataStream &) const
 {
     printElapsed();
 }
 
-void TimeCommand::decode(QDataStream&)
+void TimeCommand::decode(QDataStream &)
 {
     printElapsed();
 }
 
-
 ImageDetailsRequest::ImageDetailsRequest(ImageId _imageId)
-    :RemoteCommand(CommandType::ImageDetailsRequest), imageId(_imageId)
+    : RemoteCommand(CommandType::ImageDetailsRequest)
+    , imageId(_imageId)
 {
     addSerializer(new Serializer<ImageId>(imageId));
 }
 
 ImageDetailsResult::ImageDetailsResult()
-    :RemoteCommand(CommandType::ImageDetailsResult)
+    : RemoteCommand(CommandType::ImageDetailsResult)
 {
     addSerializer(new Serializer<QString>(fileName));
     addSerializer(new Serializer<QString>(date));
     addSerializer(new Serializer<QString>(description));
-    addSerializer(new Serializer<QMap<QString,CategoryItemDetailsList>>(categories));
+    addSerializer(new Serializer<QMap<QString, CategoryItemDetailsList>>(categories));
 }
 
-                   //// WHAT WHAT WHAT
-QDataStream& operator<<(QDataStream& stream, const CategoryItemDetails& item)
+//// WHAT WHAT WHAT
+QDataStream &operator<<(QDataStream &stream, const CategoryItemDetails &item)
 {
     stream << item.name << item.age;
     return stream;
 }
 
-QDataStream& operator>>(QDataStream& stream, CategoryItemDetails& item)
+QDataStream &operator>>(QDataStream &stream, CategoryItemDetails &item)
 {
     stream >> item.name >> item.age;
     return stream;
 }
 
-CategoryItemsResult::CategoryItemsResult(const QStringList& _items)
-    :RemoteCommand(CommandType::CategoryItemsResult), items(_items)
+CategoryItemsResult::CategoryItemsResult(const QStringList &_items)
+    : RemoteCommand(CommandType::CategoryItemsResult)
+    , items(_items)
 {
     addSerializer(new Serializer<QStringList>(items));
 }
 
 StaticImageRequest::StaticImageRequest(int _size)
-    :RemoteCommand(CommandType::StaticImageRequest), size(_size)
+    : RemoteCommand(CommandType::StaticImageRequest)
+    , size(_size)
 {
     addSerializer(new Serializer<int>(size));
 }
 
-StaticImageResult::StaticImageResult(const QImage& _homeIcon, const QImage& _kphotoalbumIcon, const QImage& _discoverIcon)
-    :RemoteCommand(CommandType::StaticImageResult), homeIcon(_homeIcon), kphotoalbumIcon(_kphotoalbumIcon), discoverIcon(_discoverIcon)
+StaticImageResult::StaticImageResult(const QImage &_homeIcon, const QImage &_kphotoalbumIcon, const QImage &_discoverIcon)
+    : RemoteCommand(CommandType::StaticImageResult)
+    , homeIcon(_homeIcon)
+    , kphotoalbumIcon(_kphotoalbumIcon)
+    , discoverIcon(_discoverIcon)
 {
     addSerializer(new Serializer<QImage>(homeIcon, BackgroundType::Transparent));
     addSerializer(new Serializer<QImage>(kphotoalbumIcon, BackgroundType::Transparent));
     addSerializer(new Serializer<QImage>(discoverIcon, BackgroundType::Transparent));
 }
 
-ToggleTokenRequest::ToggleTokenRequest(ImageId _imageId, const QString& _token, State _state)
-    :RemoteCommand(CommandType::ToggleTokenRequest), imageId(_imageId), token(_token), state(_state)
+ToggleTokenRequest::ToggleTokenRequest(ImageId _imageId, const QString &_token, State _state)
+    : RemoteCommand(CommandType::ToggleTokenRequest)
+    , imageId(_imageId)
+    , token(_token)
+    , state(_state)
 {
     addSerializer(new Serializer<ImageId>(imageId));
     addSerializer(new Serializer<QString>(token));
