@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2019 The KPhotoAlbum Development Team
+/* Copyright (C) 2003-2020 The KPhotoAlbum Development Team
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -19,35 +19,35 @@
 
 #include "SettingsData.h"
 
-#include <DB/CategoryCollection.h>
-#include <DB/ImageDB.h>
-
 #include <KConfig>
 #include <KConfigGroup>
 #include <KLocalizedString>
-#include <KMessageBox>
 #include <KSharedConfig>
-#include <QApplication>
-#include <QPixmapCache>
 #include <QStringList>
-#include <stdlib.h>
+#include <QThread>
 
+namespace
+{
+// when used from an application with different component name
+// (e.g. kpa-thumbnailtool), we need to explicitly set the component name:
+const QString configFile = QString::fromLatin1("kphotoalbumrc");
+}
 #define STR(x) QString::fromLatin1(x)
 
-#define value(GROUP, OPTION, DEFAULT) \
-    KSharedConfig::openConfig()->group(GROUP).readEntry(OPTION, DEFAULT)
+#define cfgValue(GROUP, OPTION, DEFAULT) \
+    KSharedConfig::openConfig(configFile)->group(GROUP).readEntry(OPTION, DEFAULT)
 
-#define setValue(GROUP, OPTION, VALUE)                                  \
-    {                                                                   \
-        KConfigGroup group = KSharedConfig::openConfig()->group(GROUP); \
-        group.writeEntry(OPTION, VALUE);                                \
-        group.sync();                                                   \
-    }
+#define setValue(GROUP, OPTION, VALUE)                                            \
+    do {                                                                          \
+        KConfigGroup group = KSharedConfig::openConfig(configFile)->group(GROUP); \
+        group.writeEntry(OPTION, VALUE);                                          \
+        group.sync();                                                             \
+    } while (0)
 
-#define getValueFunc_(TYPE, FUNC, GROUP, OPTION, DEFAULT) \
-    TYPE SettingsData::FUNC() const                       \
-    {                                                     \
-        return (TYPE)value(GROUP, OPTION, DEFAULT);       \
+#define getValueFunc_(TYPE, FUNC, GROUP, OPTION, DEFAULT)           \
+    TYPE SettingsData::FUNC() const                                 \
+    {                                                               \
+        return static_cast<TYPE>(cfgValue(GROUP, OPTION, DEFAULT)); \
     }
 
 #define setValueFunc_(FUNC, TYPE, GROUP, OPTION, VALUE) \
@@ -63,13 +63,13 @@
 #define property_(GET_TYPE, GET_FUNC, GET_VALUE, SET_FUNC, SET_TYPE, SET_VALUE, GROUP, OPTION, GET_DEFAULT_1, GET_DEFAULT_2, GET_DEFAULT_2_TYPE) \
     GET_TYPE SettingsData::GET_FUNC() const                                                                                                      \
     {                                                                                                                                            \
-        KConfigGroup g = KSharedConfig::openConfig()->group(GROUP);                                                                              \
+        const KConfigGroup g = KSharedConfig::openConfig(configFile)->group(GROUP);                                                              \
                                                                                                                                                  \
         if (!g.hasKey(OPTION))                                                                                                                   \
             return GET_DEFAULT_1;                                                                                                                \
                                                                                                                                                  \
-        GET_DEFAULT_2_TYPE v = g.readEntry(OPTION, (GET_DEFAULT_2_TYPE)GET_DEFAULT_2);                                                           \
-        return (GET_TYPE)GET_VALUE;                                                                                                              \
+        GET_DEFAULT_2_TYPE v = g.readEntry(OPTION, static_cast<GET_DEFAULT_2_TYPE>(GET_DEFAULT_2));                                              \
+        return static_cast<GET_TYPE>(GET_VALUE);                                                                                                 \
     }                                                                                                                                            \
     setValueFunc_(SET_FUNC, SET_TYPE, GROUP, OPTION, SET_VALUE)
 
@@ -87,10 +87,15 @@
     property(TYPE, GET_FUNC, SET_FUNC, TYPE &, v, #GROUP, #GET_FUNC, GET_DEFAULT)
 
 #define property_enum(GET_FUNC, SET_FUNC, TYPE, GROUP, GET_DEFAULT) \
-    property(TYPE, GET_FUNC, SET_FUNC, TYPE, (int)v, #GROUP, #GET_FUNC, (int)GET_DEFAULT)
+    property(TYPE, GET_FUNC, SET_FUNC, TYPE, static_cast<int>(v), #GROUP, #GET_FUNC, static_cast<int>(GET_DEFAULT))
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+#define property_sset(GET_FUNC, SET_FUNC, GROUP, GET_DEFAULT) \
+    property_(StringSet, GET_FUNC, (StringSet{ v.begin(), v.end() }), SET_FUNC, StringSet &, (QStringList{ v.begin(), v.end() }), #GROUP, #GET_FUNC, GET_DEFAULT, QStringList(), QStringList)
+#else
 #define property_sset(GET_FUNC, SET_FUNC, GROUP, GET_DEFAULT) \
     property_(StringSet, GET_FUNC, v.toSet(), SET_FUNC, StringSet &, v.toList(), #GROUP, #GET_FUNC, GET_DEFAULT, QStringList(), QStringList)
+#endif
 
 /**
  * smoothScale() is called from the image loading thread, therefore we need
@@ -108,7 +113,7 @@ SettingsData *SettingsData::s_instance = nullptr;
 SettingsData *SettingsData::instance()
 {
     if (!s_instance)
-        qFatal("instance called before loading a setup!");
+        qFatal("SettingsData: instance called before loading a setup!");
 
     return s_instance;
 }
@@ -118,24 +123,25 @@ bool SettingsData::ready()
     return s_instance;
 }
 
-void SettingsData::setup(const QString &imageDirectory)
+void SettingsData::setup(const QString &imageDirectory, DB::UIDelegate &delegate)
 {
     if (!s_instance)
-        s_instance = new SettingsData(imageDirectory);
+        s_instance = new SettingsData(imageDirectory, delegate);
 }
 
-SettingsData::SettingsData(const QString &imageDirectory)
+SettingsData::SettingsData(const QString &imageDirectory, DB::UIDelegate &delegate)
+    : m_UI(delegate)
 {
     m_hasAskedAboutTimeStamps = false;
 
-    QString s = STR("/");
+    const QString s = STR("/");
     m_imageDirectory = imageDirectory.endsWith(s) ? imageDirectory : imageDirectory + s;
 
-    _smoothScale = value("Viewer", "smoothScale", true);
+    _smoothScale = cfgValue("Viewer", "smoothScale", true);
 
     // Split the list of Exif comments that should be stripped automatically to a list
 
-    QStringList commentsToStrip = value("General", "commentsToStrip", QString::fromLatin1("Exif_JPEG_PICTURE-,-OLYMPUS DIGITAL CAMERA-,-JENOPTIK DIGITAL CAMERA-,-")).split(QString::fromLatin1("-,-"), QString::SkipEmptyParts);
+    QStringList commentsToStrip = cfgValue("General", "commentsToStrip", QString::fromLatin1("Exif_JPEG_PICTURE-,-OLYMPUS DIGITAL CAMERA-,-JENOPTIK DIGITAL CAMERA-,-")).split(QString::fromLatin1("-,-"), QString::SkipEmptyParts);
     for (QString &comment : commentsToStrip)
         comment.replace(QString::fromLatin1(",,"), QString::fromLatin1(","));
 
@@ -169,10 +175,18 @@ property_copy(excludeDirectories, setExcludeDirectories, QString, General, QStri
 property_copy(recentAndroidAddress, setRecentAndroidAddress, QString, General, QString())
 property_copy(listenForAndroidDevicesOnStartup, setListenForAndroidDevicesOnStartup, bool, General, false)
 #endif
+getValueFunc(QString, colorScheme, General, QString())
+void SettingsData::setColorScheme(const QString &path) {
+    if (path != colorScheme())
+    {
+        setValue("General", "colorScheme", path);
+        emit colorSchemeChanged();
+    }
+}
 
 getValueFunc(QSize, histogramSize, General, QSize(15, 30))
-getValueFunc(ViewSortType, viewSortType, General, (int)SortLastUse)
-getValueFunc(AnnotationDialog::MatchType, matchType, General, (int)AnnotationDialog::MatchFromWordStart)
+getValueFunc(ViewSortType, viewSortType, General, static_cast<int>(SortLastUse))
+getValueFunc(AnnotationDialog::MatchType, matchType, General, static_cast<int>(AnnotationDialog::MatchFromWordStart))
 getValueFunc(bool, histogramUseLinearScale, General, false)
 
     // clang-format on
@@ -199,7 +213,7 @@ void SettingsData::setViewSortType(const ViewSortType tp)
     if (tp == viewSortType())
         return;
 
-    setValue("General", "viewSortType", (int)tp);
+    setValue("General", "viewSortType", static_cast<int>(tp));
     emit viewSortTypeChanged(tp);
 }
 void SettingsData::setMatchType(const AnnotationDialog::MatchType mt)
@@ -207,7 +221,7 @@ void SettingsData::setMatchType(const AnnotationDialog::MatchType mt)
     if (mt == matchType())
         return;
 
-    setValue("General", "matchType", (int)mt);
+    setValue("General", "matchType", static_cast<int>(mt));
     emit matchTypeChanged(mt);
 }
 
@@ -219,16 +233,15 @@ bool SettingsData::trustTimeStamps()
         return false;
     else {
         if (!m_hasAskedAboutTimeStamps) {
-            QApplication::setOverrideCursor(Qt::ArrowCursor);
-            QString txt = i18n("When reading time information of images, their Exif info is used. "
-                               "Exif info may, however, not be supported by your KPhotoAlbum installation, "
-                               "or no valid information may be in the file. "
-                               "As a backup, KPhotoAlbum may use the timestamp of the image - this may, "
-                               "however, not be valid in case the image is scanned in. "
-                               "So the question is, should KPhotoAlbum trust the time stamp on your images?");
-            int answer = KMessageBox::questionYesNo(nullptr, txt, i18n("Trust Time Stamps?"));
-            QApplication::restoreOverrideCursor();
-            if (answer == KMessageBox::Yes)
+            const QString txt = i18n("When reading time information of images, their Exif info is used. "
+                                     "Exif info may, however, not be supported by your KPhotoAlbum installation, "
+                                     "or no valid information may be in the file. "
+                                     "As a backup, KPhotoAlbum may use the timestamp of the image - this may, "
+                                     "however, not be valid in case the image is scanned in. "
+                                     "So the question is, should KPhotoAlbum trust the time stamp on your images?");
+            const QString logMsg = QString::fromUtf8("Trust timestamps for this session?");
+            auto answer = uiDelegate().questionYesNo(logMsg, txt, i18n("Trust Time Stamps?"));
+            if (answer == DB::UserFeedback::Confirm)
                 m_trustTimeStamps = true;
             else
                 m_trustTimeStamps = false;
@@ -250,6 +263,11 @@ property_copy(moveOriginalContents, setMoveOriginalContents, bool, FileVersionDe
 property_copy(autoStackNewFiles, setAutoStackNewFiles, bool, FileVersionDetection, true)
 property_copy(copyFileComponent, setCopyFileComponent, QString, FileVersionDetection, "(.[^.]+)$")
 property_copy(copyFileReplacementComponent, setCopyFileReplacementComponent, QString, FileVersionDetection, "-edited\\1")
+property_copy(loadOptimizationPreset, setLoadOptimizationPreset, int, FileVersionDetection, 0)
+property_copy(overlapLoadMD5, setOverlapLoadMD5, bool, FileVersionDetection, false)
+property_copy(preloadThreadCount, setPreloadThreadCount, int, FileVersionDetection, 1)
+property_copy(thumbnailPreloadThreadCount, setThumbnailPreloadThreadCount, int, FileVersionDetection, 1)
+property_copy(thumbnailBuilderThreadCount, setThumbnailBuilderThreadCount, int, FileVersionDetection, 0)
     // clang-format on
 
     ////////////////////
@@ -268,7 +286,6 @@ property_copy(thumbnailSpace, setThumbnailSpace, int, Thumbnails, 4)
 property_copy(minimumThumbnailSize, setMinimumThumbnailSize, int, Thumbnails, 32)
 property_copy(maximumThumbnailSize, setMaximumThumbnailSize, int, Thumbnails, 4096)
 property_enum(thumbnailAspectRatio, setThumbnailAspectRatio, ThumbnailAspectRatio, Thumbnails, Aspect_3_2)
-property_ref(backgroundColor, setBackgroundColor, QString, Thumbnails, QColor(Qt::darkGray).name())
 property_copy(incrementalThumbnails, setIncrementalThumbnails, bool, Thumbnails, true)
 
 // database specific so that changing it doesn't invalidate the thumbnail cache for other databases:
@@ -288,7 +305,7 @@ getValueFunc_(int, thumbnailSize, groupForDatabase("Thumbnails"), "thumbSize", 2
 int SettingsData::actualThumbnailSize() const
 {
     // this is database specific since it's a derived value of thumbnailSize
-    int retval = value(groupForDatabase("Thumbnails"), "actualThumbSize", 0);
+    int retval = cfgValue(groupForDatabase("Thumbnails"), "actualThumbSize", 0);
     // if no value has been set, use thumbnailSize
     if (retval == 0)
         retval = thumbnailSize();
@@ -297,8 +314,6 @@ int SettingsData::actualThumbnailSize() const
 
 void SettingsData::setActualThumbnailSize(int value)
 {
-    QPixmapCache::clear();
-
     // enforce limits:
     value = qBound(minimumThumbnailSize(), value, thumbnailSize());
 
@@ -349,20 +364,6 @@ void SettingsData::setSmoothScale(bool b)
 //// Categories ////
 ////////////////////
 
-setValueFunc(setAlbumCategory, QString &, General, albumCategory)
-
-    QString SettingsData::albumCategory() const
-{
-    QString category = value("General", "albumCategory", STR(""));
-
-    if (!DB::ImageDB::instance()->categoryCollection()->categoryNames().contains(category)) {
-        category = DB::ImageDB::instance()->categoryCollection()->categoryNames()[0];
-        const_cast<SettingsData *>(this)->setAlbumCategory(category);
-    }
-
-    return category;
-}
-
 // clang-format off
 property_ref(untaggedCategory, setUntaggedCategory, QString, General, i18n("Events"))
 property_ref(untaggedTag, setUntaggedTag, QString, General, i18n("untagged"))
@@ -375,7 +376,7 @@ property_copy(untaggedImagesTagVisible, setUntaggedImagesTagVisible, bool, Gener
 
     // clang-format off
 property_sset(exifForViewer, setExifForViewer, Exif, StringSet())
-property_sset(exifForDialog, setExifForDialog, Exif, Exif::Info::instance()->standardKeys())
+property_sset(exifForDialog, setExifForDialog, Exif, StringSet())
 property_ref(iptcCharset, setIptcCharset, QString, Exif, QString())
     // clang-format on
 
@@ -396,8 +397,6 @@ property_copy(updateDescription, setUpdateDescription, bool, ExifImport, false)
     ///////////////////////
 
     // clang-format off
-property_copy(delayLoadingPlugins, setDelayLoadingPlugins, bool, Plug - ins, true)
-
 property_ref_(HTMLBaseDir, setHTMLBaseDir, QString, groupForDatabase("HTML Settings"), QString::fromLocal8Bit(qgetenv("HOME")) + STR("/public_html"))
 property_ref_(HTMLBaseURL, setHTMLBaseURL, QString, groupForDatabase("HTML Settings"), STR("file://") + HTMLBaseDir())
 property_ref_(HTMLDestURL, setHTMLDestURL, QString, groupForDatabase("HTML Settings"), STR("file://") + HTMLBaseDir())
@@ -412,12 +411,11 @@ property_ref_(HTMLThumbSize, setHTMLThumbSize, int, groupForDatabase("HTML Setti
 property_ref_(HTMLNumOfCols, setHTMLNumOfCols, int, groupForDatabase("HTML Settings"), 5)
 property_ref_(HTMLSizes, setHTMLSizes, QString, groupForDatabase("HTML Settings"), STR(""))
 property_ref_(HTMLIncludeSelections, setHTMLIncludeSelections, QString, groupForDatabase("HTML Settings"), STR(""))
-property_ref_(password, setPassword, QString, groupForDatabase("Privacy Settings"), STR(""))
     // clang-format on
 
     QDate SettingsData::fromDate() const
 {
-    QString date = value("Miscellaneous", "fromDate", STR(""));
+    QString date = cfgValue("Miscellaneous", "fromDate", STR(""));
     return date.isEmpty() ? QDate(QDate::currentDate().year(), 1, 1) : QDate::fromString(date, Qt::ISODate);
 }
 
@@ -429,7 +427,7 @@ void SettingsData::setFromDate(const QDate &date)
 
 QDate SettingsData::toDate() const
 {
-    QString date = value("Miscellaneous", "toDate", STR(""));
+    QString date = cfgValue("Miscellaneous", "toDate", STR(""));
     return date.isEmpty() ? QDate(QDate::currentDate().year() + 1, 1, 1) : QDate::fromString(date, Qt::ISODate);
 }
 
@@ -449,20 +447,35 @@ QString SettingsData::groupForDatabase(const char *setting) const
     return STR("%1 - %2").arg(STR(setting)).arg(imageDirectory());
 }
 
-DB::ImageSearchInfo SettingsData::currentLock() const
+QVariantMap SettingsData::currentLock() const
 {
-    return DB::ImageSearchInfo::loadLock();
+    // duplicating logic from ImageSearchInfo here is not ideal
+    // FIXME(jzarl): review the whole database view lock mechanism
+    const auto group = groupForDatabase("Privacy Settings");
+    QVariantMap keyValuePairs;
+    keyValuePairs[STR("label")] = cfgValue(group, "label", {});
+    keyValuePairs[STR("description")] = cfgValue(group, "description", {});
+    // reading a QVariant containing a stringlist is asking too much of cfgValue:
+    const auto config = KSharedConfig::openConfig(configFile)->group(group);
+    const QStringList categories = config.readEntry<QStringList>(QString::fromUtf8("categories"), QStringList());
+    keyValuePairs[STR("categories")] = QVariant(categories);
+    for (QStringList::ConstIterator it = categories.constBegin(); it != categories.constEnd(); ++it) {
+        keyValuePairs[*it] = cfgValue(group, *it, {});
+    }
+    return keyValuePairs;
 }
 
-void SettingsData::setCurrentLock(const DB::ImageSearchInfo &info, bool exclude)
+void SettingsData::setCurrentLock(const QVariantMap &pairs, bool exclude)
 {
-    info.saveLock();
+    for (QVariantMap::const_iterator it = pairs.cbegin(); it != pairs.cend(); ++it) {
+        setValue(groupForDatabase("Privacy Settings"), it.key(), it.value());
+    }
     setValue(groupForDatabase("Privacy Settings"), "exclude", exclude);
 }
 
 bool SettingsData::lockExcludes() const
 {
-    return value(groupForDatabase("Privacy Settings"), "exclude", false);
+    return cfgValue(groupForDatabase("Privacy Settings"), "exclude", false);
 }
 
 getValueFunc_(bool, locked, groupForDatabase("Privacy Settings"), "locked", false)
@@ -483,13 +496,7 @@ void SettingsData::setWindowGeometry(WindowType win, const QRect &geometry)
 
 QRect SettingsData::windowGeometry(WindowType win) const
 {
-    return value("Window Geometry", win, QRect(0, 0, 800, 600));
-}
-
-bool Settings::SettingsData::hasUntaggedCategoryFeatureConfigured() const
-{
-    return DB::ImageDB::instance()->categoryCollection()->categoryNames().contains(untaggedCategory())
-        && DB::ImageDB::instance()->categoryCollection()->categoryForName(untaggedCategory())->items().contains(untaggedTag());
+    return cfgValue("Window Geometry", win, QRect(0, 0, 800, 600));
 }
 
 double Settings::SettingsData::getThumbnailAspectRatio() const
@@ -531,4 +538,72 @@ void Settings::SettingsData::setEXIFCommentsToStrip(QStringList EXIFCommentsToSt
     m_EXIFCommentsToStrip = EXIFCommentsToStrip;
 }
 
+bool Settings::SettingsData::getOverlapLoadMD5() const
+{
+    switch (Settings::SettingsData::instance()->loadOptimizationPreset()) {
+    case Settings::LoadOptimizationSlowNVME:
+    case Settings::LoadOptimizationFastNVME:
+        return true;
+    case Settings::LoadOptimizationManual:
+        return Settings::SettingsData::instance()->overlapLoadMD5();
+    case Settings::LoadOptimizationHardDisk:
+    case Settings::LoadOptimizationNetwork:
+    case Settings::LoadOptimizationSataSSD:
+    default:
+        return false;
+    }
+}
+
+int Settings::SettingsData::getPreloadThreadCount() const
+{
+    switch (Settings::SettingsData::instance()->loadOptimizationPreset()) {
+    case Settings::LoadOptimizationManual:
+        return Settings::SettingsData::instance()->preloadThreadCount();
+    case Settings::LoadOptimizationSlowNVME:
+    case Settings::LoadOptimizationFastNVME:
+    case Settings::LoadOptimizationSataSSD:
+        return qMax(1, qMin(16, QThread::idealThreadCount()));
+    case Settings::LoadOptimizationHardDisk:
+    case Settings::LoadOptimizationNetwork:
+    default:
+        return 1;
+    }
+}
+
+int Settings::SettingsData::getThumbnailPreloadThreadCount() const
+{
+    switch (Settings::SettingsData::instance()->loadOptimizationPreset()) {
+    case Settings::LoadOptimizationManual:
+        return Settings::SettingsData::instance()->thumbnailPreloadThreadCount();
+    case Settings::LoadOptimizationSlowNVME:
+    case Settings::LoadOptimizationFastNVME:
+    case Settings::LoadOptimizationSataSSD:
+        return qMax(1, qMin(16, QThread::idealThreadCount() / 2));
+    case Settings::LoadOptimizationHardDisk:
+    case Settings::LoadOptimizationNetwork:
+    default:
+        return 1;
+    }
+}
+
+int Settings::SettingsData::getThumbnailBuilderThreadCount() const
+{
+    switch (Settings::SettingsData::instance()->loadOptimizationPreset()) {
+    case Settings::LoadOptimizationManual:
+        return Settings::SettingsData::instance()->thumbnailBuilderThreadCount();
+    case Settings::LoadOptimizationSlowNVME:
+    case Settings::LoadOptimizationFastNVME:
+    case Settings::LoadOptimizationSataSSD:
+    case Settings::LoadOptimizationHardDisk:
+    case Settings::LoadOptimizationNetwork:
+    default:
+        return qMax(1, qMin(16, QThread::idealThreadCount() - 1));
+    }
+}
+
+DB::UIDelegate &SettingsData::uiDelegate() const
+{
+    return m_UI;
+}
+
 // vi:expandtab:tabstop=4 shiftwidth=4:
