@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2010 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2020 The KPhotoAlbum Development Team
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -22,10 +22,6 @@
 // KDE includes
 #include <KPageDialog>
 
-namespace KIPI
-{
-class ConfigWidget;
-}
 namespace Exif
 {
 class TreeView;
