@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2010 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2020 The KPhotoAlbum Development Team
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -32,8 +32,9 @@ public:
     explicit UntaggedGroupBox(QWidget *parent = 0);
     void loadSettings(Settings::SettingsData *opt);
     void saveSettings(Settings::SettingsData *opt);
-    void categoryDeleted(QString categoryName);
-    void categoryRenamed(QString oldCategoryName, QString newCategoryName);
+    void categoryAdded(const QString &categoryName);
+    void categoryDeleted(const QString &categoryName);
+    void categoryRenamed(const QString &oldCategoryName, const QString &newCategoryName);
 
 private slots:
     void populateCategoryComboBox();
