@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2019 The KPhotoAlbum Development Team
+/* Copyright (C) 2003-2020 The KPhotoAlbum Development Team
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -25,6 +25,11 @@
 class KActionCollection;
 class QSlider;
 
+namespace ImageManager
+{
+class ThumbnailCache;
+}
+
 namespace ThumbnailView
 {
 class ThumbnailModel;
@@ -38,7 +43,7 @@ class ThumbnailFacade : public QObject, public ThumbnailFactory
     Q_OBJECT
 public:
     static ThumbnailFacade *instance();
-    ThumbnailFacade();
+    ThumbnailFacade(ImageManager::ThumbnailCache *thumbnailCache);
     QWidget *gui();
     void setCurrentItem(const DB::FileName &fileName);
     void reload(SelectionUpdateMethod method);
@@ -56,19 +61,10 @@ public:
 
     /**
      * @brief filterWidget provides a FilterWidget that is connected to the ThumbnailModel.
-     * If called multiple times, the same FilterWidget will be returned.
-     * Keyboard shortcuts for the widget are included in ThumbnailFacade::actions().
      * The widget will reflect changes in the filter and can be used to set the filter.
      * @return a FilterWidget
      */
-    FilterWidget *filterWidget();
-
-    /**
-     * @brief a collection of all QActions for the ThumbnailView component.
-     * Currently, this only contains the filterWidget actions.
-     * @return the QActions for the whole thumbnail view component.
-     */
-    KActionCollection *actions();
+    FilterWidget *createFilterWidget(QWidget *parent);
 
 public slots:
     void gotoDate(const DB::ImageDate &date, bool includeRanges);
@@ -105,6 +101,7 @@ private:
     ThumbnailWidget *m_widget;
     ThumbnailPainter *m_painter;
     ThumbnailToolTip *m_toolTip;
+    ImageManager::ThumbnailCache *m_thumbnailCache;
 };
 }
 
