@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2019 The KPhotoAlbum Development Team
+/* Copyright (C) 2003-2020 The KPhotoAlbum Development Team
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -35,11 +35,12 @@
 #include <QIcon>
 #include <QLoggingCategory>
 
-ThumbnailView::ThumbnailModel::ThumbnailModel(ThumbnailFactory *factory)
+ThumbnailView::ThumbnailModel::ThumbnailModel(ThumbnailFactory *factory, const ImageManager::ThumbnailCache *thumbnailCache)
     : ThumbnailComponent(factory)
     , m_sortDirection(Settings::SettingsData::instance()->showNewestThumbnailFirst() ? NewestFirst : OldestFirst)
     , m_firstVisibleRow(-1)
     , m_lastVisibleRow(-1)
+    , m_thumbnailCache(thumbnailCache)
 {
     connect(DB::ImageDB::instance(), SIGNAL(imagesDeleted(DB::FileNameList)), this, SLOT(imagesDeletedFromDB(DB::FileNameList)));
     m_ImagePlaceholder = QIcon::fromTheme(QLatin1String("image-x-generic")).pixmap(cellGeometryInfo()->preferredIconSize());
@@ -47,16 +48,11 @@ ThumbnailView::ThumbnailModel::ThumbnailModel(ThumbnailFactory *factory)
 
     m_filter.setSearchMode(0);
     connect(this, &ThumbnailModel::filterChanged, this, &ThumbnailModel::updateDisplayModel);
-
-    m_filterWidget = new FilterWidget;
-    connect(this, &ThumbnailModel::filterChanged, m_filterWidget, &FilterWidget::setFilter);
-    connect(m_filterWidget, &FilterWidget::ratingChanged, this, &ThumbnailModel::filterByRating);
-    connect(m_filterWidget, &FilterWidget::filterToggled, this, &ThumbnailModel::toggleFilter);
 }
 
 static bool stackOrderComparator(const DB::FileName &a, const DB::FileName &b)
 {
-    return a.info()->stackOrder() < b.info()->stackOrder();
+    return DB::ImageDB::instance()->info(a)->stackOrder() < DB::ImageDB::instance()->info(b)->stackOrder();
 }
 
 void ThumbnailView::ThumbnailModel::updateDisplayModel()
@@ -75,8 +71,8 @@ void ThumbnailView::ThumbnailModel::updateDisplayModel()
     typedef QList<DB::FileName> StackList;
     typedef QMap<DB::StackID, StackList> StackMap;
     StackMap stackContents;
-    Q_FOREACH (const DB::FileName &fileName, m_imageList) {
-        DB::ImageInfoPtr imageInfo = fileName.info();
+    for (const DB::FileName &fileName : qAsConst(m_imageList)) {
+        const DB::ImageInfoPtr imageInfo = DB::ImageDB::instance()->info(fileName);
         if (imageInfo && imageInfo->isStacked()) {
             DB::StackID stackid = imageInfo->stackId();
             stackContents[stackid].append(fileName);
@@ -97,8 +93,8 @@ void ThumbnailView::ThumbnailModel::updateDisplayModel()
      */
     m_displayList = DB::FileNameList();
     QSet<DB::StackID> alreadyShownStacks;
-    Q_FOREACH (const DB::FileName &fileName, m_imageList) {
-        DB::ImageInfoPtr imageInfo = fileName.info();
+    for (const DB::FileName &fileName : qAsConst(m_imageList)) {
+        const DB::ImageInfoPtr imageInfo = DB::ImageDB::instance()->info(fileName);
         if (!m_filter.match(imageInfo))
             continue;
         if (imageInfo && imageInfo->isStacked()) {
@@ -109,7 +105,7 @@ void ThumbnailView::ThumbnailModel::updateDisplayModel()
             Q_ASSERT(found != stackContents.end());
             const StackList &orderedStack = *found;
             if (m_expandedStacks.contains(stackid)) {
-                Q_FOREACH (const DB::FileName &fileName, orderedStack) {
+                for (const DB::FileName &fileName : orderedStack) {
                     m_displayList.append(fileName);
                 }
             } else {
@@ -133,7 +129,7 @@ void ThumbnailView::ThumbnailModel::updateDisplayModel()
 
 void ThumbnailView::ThumbnailModel::toggleStackExpansion(const DB::FileName &fileName)
 {
-    DB::ImageInfoPtr imageInfo = fileName.info();
+    const DB::ImageInfoPtr imageInfo = DB::ImageDB::instance()->info(fileName);
     if (imageInfo) {
         DB::StackID stackid = imageInfo->stackId();
         model()->beginResetModel();
@@ -162,8 +158,8 @@ void ThumbnailView::ThumbnailModel::setImageList(const DB::FileNameList &items)
 {
     m_imageList = items;
     m_allStacks.clear();
-    Q_FOREACH (const DB::FileName &fileName, items) {
-        DB::ImageInfoPtr info = fileName.info();
+    for (const DB::FileName &fileName : items) {
+        const DB::ImageInfoPtr info = DB::ImageDB::instance()->info(fileName);
         if (info && info->isStacked())
             m_allStacks << info->stackId();
     }
@@ -171,7 +167,6 @@ void ThumbnailView::ThumbnailModel::setImageList(const DB::FileNameList &items)
     preloadThumbnails();
 }
 
-// TODO(hzeller) figure out if this should return the m_imageList or m_displayList.
 DB::FileNameList ThumbnailView::ThumbnailModel::imageList(Order order) const
 {
     if (order == SortedOrder && m_sortDirection == NewestFirst)
@@ -184,7 +179,7 @@ void ThumbnailView::ThumbnailModel::imagesDeletedFromDB(const DB::FileNameList &
 {
     SelectionMaintainer dummy(widget(), model());
 
-    Q_FOREACH (const DB::FileName &fileName, list) {
+    for (const DB::FileName &fileName : list) {
         m_displayList.removeAll(fileName);
         m_imageList.removeAll(fileName);
     }
@@ -213,7 +208,7 @@ void ThumbnailView::ThumbnailModel::updateIndexCache()
 {
     m_fileNameToIndex.clear();
     int index = 0;
-    Q_FOREACH (const DB::FileName &fileName, m_displayList) {
+    for (const DB::FileName &fileName : qAsConst(m_displayList)) {
         m_fileNameToIndex[fileName] = index;
         ++index;
     }
@@ -301,7 +296,7 @@ QVariant ThumbnailView::ThumbnailModel::data(const QModelIndex &index, int role)
 
 void ThumbnailView::ThumbnailModel::requestThumbnail(const DB::FileName &fileName, const ImageManager::Priority priority)
 {
-    DB::ImageInfoPtr imageInfo = fileName.info();
+    const DB::ImageInfoPtr imageInfo = DB::ImageDB::instance()->info(fileName);
     if (!imageInfo)
         return;
     // request the thumbnail in the size that is set in the settings, not in the current grid size:
@@ -322,9 +317,11 @@ void ThumbnailView::ThumbnailModel::pixmapLoaded(ImageManager::ImageRequest *req
     // As a result of the image being loaded, we emit the dataChanged signal, which in turn asks the delegate to paint the cell
     // The delegate now fetches the newly loaded image from the cache.
 
-    DB::ImageInfoPtr imageInfo = fileName.info();
-    // TODO(hzeller): figure out, why the size is set here. We do an implicit
+    DB::ImageInfoPtr imageInfo = DB::ImageDB::instance()->info(fileName);
+    // (hzeller): figure out, why the size is set here. We do an implicit
     // write here to the database.
+    // (jzarl 2020-07-25): when loading a fullsize pixmap, we get the size "for free";
+    // calculating it separately would cost us more than writing to the database from here.
     if (fullSize.isValid() && imageInfo) {
         imageInfo->setSize(fullSize);
     }
@@ -335,6 +332,7 @@ void ThumbnailView::ThumbnailModel::pixmapLoaded(ImageManager::ImageRequest *req
 QString ThumbnailView::ThumbnailModel::thumbnailText(const QModelIndex &index) const
 {
     const DB::FileName fileName = imageAt(index.row());
+    const auto info = DB::ImageDB::instance()->info(fileName);
 
     QString text;
 
@@ -344,7 +342,7 @@ QString ThumbnailView::ThumbnailModel::thumbnailText(const QModelIndex &index) c
     const int maxCharacters = thumbnailHeight / QFontMetrics(widget()->font()).maxWidth() * 2;
 
     if (Settings::SettingsData::instance()->displayLabels()) {
-        QString line = fileName.info()->label();
+        QString line = info->label();
         if (stringWidth(line) > thumbnailWidth) {
             line = line.left(maxCharacters);
             line += QLatin1String(" ...");
@@ -353,13 +351,13 @@ QString ThumbnailView::ThumbnailModel::thumbnailText(const QModelIndex &index) c
     }
 
     if (Settings::SettingsData::instance()->displayCategories()) {
-        QStringList grps = fileName.info()->availableCategories();
+        QStringList grps = info->availableCategories();
         for (QStringList::const_iterator it = grps.constBegin(); it != grps.constEnd(); ++it) {
             QString category = *it;
             if (category != i18n("Folder") && category != i18n("Media Type")) {
-                Utilities::StringSet items = fileName.info()->itemsOfCategory(category);
+                Utilities::StringSet items = info->itemsOfCategory(category);
 
-                if (Settings::SettingsData::instance()->hasUntaggedCategoryFeatureConfigured()
+                if (DB::ImageDB::instance()->untaggedCategoryFeatureConfigured()
                     && !Settings::SettingsData::instance()->untaggedImagesTagVisible()) {
 
                     if (category == Settings::SettingsData::instance()->untaggedCategory()) {
@@ -405,6 +403,8 @@ void ThumbnailView::ThumbnailModel::updateCell(const QModelIndex &index)
 
 void ThumbnailView::ThumbnailModel::updateCell(const DB::FileName &fileName)
 {
+    if (fileName.isNull())
+        return;
     updateCell(indexOf(fileName));
 }
 
@@ -421,13 +421,13 @@ QPixmap ThumbnailView::ThumbnailModel::pixmap(const DB::FileName &fileName) cons
     if (m_overrideFileName == fileName)
         return m_overrideImage;
 
-    const DB::ImageInfoPtr imageInfo = fileName.info();
+    const DB::ImageInfoPtr imageInfo = DB::ImageDB::instance()->info(fileName);
     if (imageInfo == DB::ImageInfoPtr(nullptr))
         return QPixmap();
 
-    if (ImageManager::ThumbnailCache::instance()->contains(fileName)) {
+    if (m_thumbnailCache->contains(fileName)) {
         // the cached thumbnail needs to be scaled to the actual thumbnail size:
-        return ImageManager::ThumbnailCache::instance()->lookup(fileName).scaled(cellGeometryInfo()->preferredIconSize(), Qt::KeepAspectRatio);
+        return m_thumbnailCache->lookup(fileName).scaled(cellGeometryInfo()->preferredIconSize(), Qt::KeepAspectRatio);
     }
 
     const_cast<ThumbnailView::ThumbnailModel *>(this)->requestThumbnail(fileName, ImageManager::ThumbnailVisible);
@@ -442,9 +442,14 @@ bool ThumbnailView::ThumbnailModel::isFiltered() const
     return !m_filter.isNull();
 }
 
-ThumbnailView::FilterWidget *ThumbnailView::ThumbnailModel::filterWidget()
+ThumbnailView::FilterWidget *ThumbnailView::ThumbnailModel::createFilterWidget(QWidget *parent)
 {
-    return m_filterWidget;
+
+    auto filterWidget = new FilterWidget(parent);
+    connect(this, &ThumbnailModel::filterChanged, filterWidget, &FilterWidget::setFilter);
+    connect(filterWidget, &FilterWidget::ratingChanged, this, &ThumbnailModel::filterByRating);
+    connect(filterWidget, &FilterWidget::filterToggled, this, &ThumbnailModel::toggleFilter);
+    return filterWidget;
 }
 
 bool ThumbnailView::ThumbnailModel::thumbnailStillNeeded(int row) const
@@ -533,11 +538,11 @@ void ThumbnailView::ThumbnailModel::preloadThumbnails()
 {
     // FIXME: it would make a lot of sense to merge preloadThumbnails() with pixmap()
     // and maybe also move the caching stuff into the ImageManager
-    Q_FOREACH (const DB::FileName &fileName, m_displayList) {
+    for (const DB::FileName &fileName : qAsConst(m_displayList)) {
         if (fileName.isNull())
             continue;
 
-        if (ImageManager::ThumbnailCache::instance()->contains(fileName))
+        if (m_thumbnailCache->contains(fileName))
             continue;
         const_cast<ThumbnailView::ThumbnailModel *>(this)->requestThumbnail(fileName, ImageManager::ThumbnailInvisible);
     }
