@@ -17,7 +17,7 @@
 */
 #ifndef THUMBNAILREQUEST_H
 #define THUMBNAILREQUEST_H
-#include "ImageManager/ImageRequest.h"
+#include <ImageManager/ImageRequest.h>
 
 namespace ThumbnailView
 {
@@ -26,15 +26,14 @@ class ThumbnailModel;
 class ThumbnailRequest : public ImageManager::ImageRequest
 {
 public:
-    ThumbnailRequest( int row, const DB::FileName& fileName, const QSize& size, int angle, ThumbnailModel* client);
+    ThumbnailRequest(int row, const DB::FileName &fileName, const QSize &size, int angle, ThumbnailModel *client);
     bool stillNeeded() const override;
 
 private:
-    const ThumbnailModel* const m_thumbnailModel;
+    const ThumbnailModel *const m_thumbnailModel;
     int m_row;
 };
 
-
 }
 
 #endif /* THUMBNAILREQUEST_H */
