@@ -17,10 +17,13 @@
 */
 
 #include "ElementWriter.h"
+
 #include <QXmlStreamWriter>
 
 XMLDB::ElementWriter::ElementWriter(QXmlStreamWriter &writer, const QString &elementName, bool writeAtOnce)
-    :m_writer(writer), m_elementName(elementName), m_haveWrittenStartTag(writeAtOnce)
+    : m_writer(writer)
+    , m_elementName(elementName)
+    , m_haveWrittenStartTag(writeAtOnce)
 {
     if (writeAtOnce)
         m_writer.writeStartElement(m_elementName);
@@ -28,17 +31,16 @@ XMLDB::ElementWriter::ElementWriter(QXmlStreamWriter &writer, const QString &ele
 
 void XMLDB::ElementWriter::writeStartElement()
 {
-    if ( m_haveWrittenStartTag )
+    if (m_haveWrittenStartTag)
         return;
 
     m_haveWrittenStartTag = true;
     m_writer.writeStartElement(m_elementName);
 }
 
-
 XMLDB::ElementWriter::~ElementWriter()
 {
-    if ( m_haveWrittenStartTag)
+    if (m_haveWrittenStartTag)
         m_writer.writeEndElement();
 }
 // vi:expandtab:tabstop=4 shiftwidth=4:
