@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2019 The KPhotoAlbum Development Team
+/* Copyright (C) 2003-2020 The KPhotoAlbum Development Team
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -30,6 +30,7 @@
 #include <Utilities/List.h>
 
 #include <KLocalizedString>
+#include <QElapsedTimer>
 #include <QFile>
 #include <QFileInfo>
 #include <QXmlStreamWriter>
@@ -73,9 +74,9 @@ void XMLDB::FileWriter::save(const QString &fileName, bool isAutoSave)
             i18n("Error while saving..."));
         return;
     }
-    QTime t;
+    QElapsedTimer timer;
     if (TimingLog().isDebugEnabled())
-        t.start();
+        timer.start();
     QXmlStreamWriter writer(&out);
     writer.setAutoFormatting(true);
     writer.writeStartDocument();
@@ -92,7 +93,7 @@ void XMLDB::FileWriter::save(const QString &fileName, bool isAutoSave)
         //saveSettings(writer);
     }
     writer.writeEndDocument();
-    qCDebug(TimingLog) << "XMLDB::FileWriter::save(): Saving took" << t.elapsed() << "ms";
+    qCDebug(TimingLog) << "XMLDB::FileWriter::save(): Saving took" << timer.elapsed() << "ms";
 
     // State: index.xml has previous DB version, index.xml.tmp has the current version.
 
@@ -142,18 +143,11 @@ void XMLDB::FileWriter::saveCategories(QXmlStreamWriter &writer)
             writer.writeAttribute(QString::fromUtf8("meta"), QString::fromUtf8("tokens"));
         }
 
-        // FIXME (l3u):
-        // Correct me if I'm wrong, but we don't need this, as the tags used as groups are
-        // added to the respective category anyway when they're created, so there's no need to
-        // re-add them here. Apart from this, adding an empty group (one without members) does
-        // add an empty tag ("") doing so.
-        /*
-        QStringList list =
-                Utilities::mergeListsUniqly(category->items(),
-                                            m_db->_members.groups(name));
-        */
-
-        Q_FOREACH (const QString &tagName, category->items()) {
+        // As bug 423334 shows, it is easy to forget to add a group to the respective category
+        // when it's created. We can not enforce correct creation of member groups in our API,
+        // but we can prevent incorrect data from entering index.xml.
+        const auto categoryItems = Utilities::mergeListsUniqly(category->items(), m_db->memberMap().groups(name));
+        for (const QString &tagName : categoryItems) {
             ElementWriter dummy(writer, QString::fromLatin1("value"));
             writer.writeAttribute(QString::fromLatin1("value"), tagName);
             writer.writeAttribute(QString::fromLatin1("id"),
@@ -170,14 +164,15 @@ void XMLDB::FileWriter::saveImages(QXmlStreamWriter &writer)
     DB::ImageInfoList list = m_db->m_images;
 
     // Copy files from clipboard to end of overview, so we don't loose them
-    Q_FOREACH (const DB::ImageInfoPtr &infoPtr, m_db->m_clipboard) {
+    const auto clipBoardImages = m_db->m_clipboard;
+    for (const DB::ImageInfoPtr &infoPtr : clipBoardImages) {
         list.append(infoPtr);
     }
 
     {
         ElementWriter dummy(writer, QString::fromLatin1("images"));
 
-        Q_FOREACH (const DB::ImageInfoPtr &infoPtr, list) {
+        for (const DB::ImageInfoPtr &infoPtr : qAsConst(list)) {
             save(writer, infoPtr);
         }
     }
@@ -186,10 +181,14 @@ void XMLDB::FileWriter::saveImages(QXmlStreamWriter &writer)
 void XMLDB::FileWriter::saveBlockList(QXmlStreamWriter &writer)
 {
     ElementWriter dummy(writer, QString::fromLatin1("blocklist"));
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+    QList<DB::FileName> blockList(m_db->m_blockList.begin(), m_db->m_blockList.end());
+#else
     QList<DB::FileName> blockList = m_db->m_blockList.toList();
+#endif
     // sort blocklist to get diffable files
     std::sort(blockList.begin(), blockList.end());
-    Q_FOREACH (const DB::FileName &block, blockList) {
+    for (const DB::FileName &block : qAsConst(blockList)) {
         ElementWriter dummy(writer, QString::fromLatin1("block"));
         writer.writeAttribute(QString::fromLatin1("file"), block.relative());
     }
@@ -224,12 +223,12 @@ void XMLDB::FileWriter::saveMemberGroups(QXmlStreamWriter &writer)
             }
 
             if (useCompressedFileFormat()) {
-                StringSet members = groupMapIt.value();
+                const StringSet members = groupMapIt.value();
                 ElementWriter dummy(writer, QString::fromLatin1("member"));
                 writer.writeAttribute(QString::fromLatin1("category"), categoryName);
                 writer.writeAttribute(QString::fromLatin1("group-name"), groupMapIt.key());
                 QStringList idList;
-                Q_FOREACH (const QString &member, members) {
+                for (const QString &member : members) {
                     DB::CategoryPtr catPtr = m_db->m_categoryCollection.categoryForName(categoryName);
                     XMLCategory *category = static_cast<XMLCategory *>(catPtr.data());
                     if (category->idForName(member) == 0)
@@ -239,9 +238,14 @@ void XMLDB::FileWriter::saveMemberGroups(QXmlStreamWriter &writer)
                 std::sort(idList.begin(), idList.end());
                 writer.writeAttribute(QString::fromLatin1("members"), idList.join(QString::fromLatin1(",")));
             } else {
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+                const auto groupMapItValue = groupMapIt.value();
+                QStringList members(groupMapItValue.begin(), groupMapItValue.end());
+#else
                 QStringList members = groupMapIt.value().toList();
+#endif
                 std::sort(members.begin(), members.end());
-                Q_FOREACH (const QString &member, members) {
+                for (const QString &member : qAsConst(members)) {
                     ElementWriter dummy(writer, QString::fromLatin1("member"));
                     writer.writeAttribute(QString::fromLatin1("category"), memberMapIt.key());
                     writer.writeAttribute(QString::fromLatin1("group-name"), groupMapIt.key());
@@ -344,13 +348,20 @@ void XMLDB::FileWriter::writeCategories(QXmlStreamWriter &writer, const DB::Imag
     ElementWriter topElm(writer, QString::fromLatin1("options"), false);
 
     QStringList grps = info->availableCategories();
-    Q_FOREACH (const QString &name, grps) {
+    // in contrast to CategoryCollection::categories, availableCategories is randomly sorted (since it is now a QHash)
+    grps.sort();
+    for (const QString &name : grps) {
         if (!shouldSaveCategory(name))
             continue;
 
         ElementWriter categoryElm(writer, QString::fromLatin1("option"), false);
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+        const auto itemsOfCategory = info->itemsOfCategory(name);
+        QStringList items(itemsOfCategory.begin(), itemsOfCategory.end());
+#else
         QStringList items = info->itemsOfCategory(name).toList();
+#endif
         std::sort(items.begin(), items.end());
         if (!items.isEmpty()) {
             topElm.writeStartElement();
@@ -358,7 +369,7 @@ void XMLDB::FileWriter::writeCategories(QXmlStreamWriter &writer, const DB::Imag
             writer.writeAttribute(QString::fromLatin1("name"), name);
         }
 
-        Q_FOREACH (const QString &itemValue, items) {
+        for (const QString &itemValue : qAsConst(items)) {
             ElementWriter dummy(writer, QString::fromLatin1("value"));
             writer.writeAttribute(QString::fromLatin1("value"), itemValue);
 
@@ -374,18 +385,18 @@ void XMLDB::FileWriter::writeCategoriesCompressed(QXmlStreamWriter &writer, cons
 {
     QMap<QString, QList<QPair<QString, QRect>>> positionedTags;
 
-    QList<DB::CategoryPtr> categoryList = DB::ImageDB::instance()->categoryCollection()->categories();
-    Q_FOREACH (const DB::CategoryPtr &category, categoryList) {
+    const QList<DB::CategoryPtr> categoryList = DB::ImageDB::instance()->categoryCollection()->categories();
+    for (const DB::CategoryPtr &category : categoryList) {
         QString categoryName = category->name();
 
         if (!shouldSaveCategory(categoryName))
             continue;
 
-        StringSet items = info->itemsOfCategory(categoryName);
+        const StringSet items = info->itemsOfCategory(categoryName);
         if (!items.empty()) {
             QStringList idList;
 
-            Q_FOREACH (const QString &itemValue, items) {
+            for (const QString &itemValue : items) {
                 QRect area = info->areaForTag(categoryName, itemValue);
 
                 if (area.isValid()) {
@@ -424,7 +435,7 @@ void XMLDB::FileWriter::writeCategoriesCompressed(QXmlStreamWriter &writer, cons
             QList<QPair<QString, QRect>> areas = categoryWithAreas.value();
             std::sort(areas.begin(), areas.end(),
                       [](QPair<QString, QRect> a, QPair<QString, QRect> b) { return a.first < b.first; });
-            Q_FOREACH (const auto &positionedTag, areas) {
+            for (const auto &positionedTag : qAsConst(areas)) {
                 ElementWriter dummy(writer, QString::fromLatin1("value"));
                 writer.writeAttribute(QString::fromLatin1("value"), positionedTag.first);
                 writer.writeAttribute(QString::fromLatin1("area"), areaToString(positionedTag.second));
@@ -480,8 +491,7 @@ QString XMLDB::FileWriter::escape(const QString &str)
     if (useCompressedFileFormat()) {
         while ((pos = rx.indexIn(tmp, pos)) != -1) {
             QString before = rx.cap(1);
-            QString after;
-            after.sprintf("_.%0X", rx.cap(1).data()->toLatin1());
+            QString after = QString::asprintf("_.%0X", rx.cap(1).data()->toLatin1());
             tmp.replace(pos, before.length(), after);
             pos += after.length();
         }
