@@ -19,24 +19,28 @@
 #define NUMBEREDBACKUP_H
 #include <QStringList>
 
-namespace DB {
+namespace DB
+{
 class UIDelegate;
 }
 
-namespace XMLDB {
-    class NumberedBackup
-    {
-    public:
-        explicit NumberedBackup( DB::UIDelegate &ui );
-        void makeNumberedBackup();
-    protected:
-        int getMaxId() const;
-        QStringList backupFiles() const;
-        int idForFile( const QString& fileName, bool& OK ) const;
-        void deleteOldBackupFiles();
-    private:
-        DB::UIDelegate &m_ui;
-    };
+namespace XMLDB
+{
+class NumberedBackup
+{
+public:
+    explicit NumberedBackup(DB::UIDelegate &ui);
+    void makeNumberedBackup();
+
+protected:
+    int getMaxId() const;
+    QStringList backupFiles() const;
+    int idForFile(const QString &fileName, bool &OK) const;
+    void deleteOldBackupFiles();
+
+private:
+    DB::UIDelegate &m_ui;
+};
 }
 
 #endif /* NUMBEREDBACKUP_H */
