@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2010 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2020 The KPhotoAlbum Development Team
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -24,7 +24,7 @@
 
 namespace DB
 {
-class FileNameList;
+class ImageInfoList;
 }
 
 namespace XMLDB
@@ -32,7 +32,7 @@ namespace XMLDB
 class XMLImageDateCollection : public DB::ImageDateCollection
 {
 public:
-    explicit XMLImageDateCollection(const DB::FileNameList &);
+    explicit XMLImageDateCollection(const DB::ImageInfoList &);
 
 public:
     DB::ImageCount count(const DB::ImageDate &range) override;
